# API Reference

## Classes

```{eval-rst}
.. currentmodule:: pydims

.. autosummary::
   :toctree: ../generated/classes
   :template: class-template.rst
   :recursive:

   CreationFunctions
   DimensionedArray
   DimensionError
   UnitsError
```

## Top-level functions

### General

```{eval-rst}
.. autosummary::
   :toctree: ../generated/functions
   :recursive:

   exp
```

### Reduction functions

```{eval-rst}
.. autosummary::
   :toctree: ../generated/functions
   :recursive:

   all
   any
   max
   mean
   min
   prod
   sum
   std
   var
```

### Manipulation functions

```{eval-rst}
.. autosummary::
   :toctree: ../generated/functions
   :recursive:

   broadcast_to
   concat
   expand_dims
   flatten
   fold
   moveaxis
   permute_dims
   reshape
   squeeze
   stack
```

### Indexing functions

```{eval-rst}
.. autosummary::
   :toctree: ../generated/functions
   :recursive:

   take
```

## Submodules

```{eval-rst}
.. autosummary::
   :toctree: ../generated/modules
   :template: module-template.rst
   :recursive:
```
